/*Copyright (C) 2018 Laboratório de Novas Tecnologias
Centro de Ciências da Educação (CED) - Universidade Federal de Santa Catarina

This file is part of plataformaintegrada.

Permission is hereby granted, free of charge, to any person obtaining a copy of this
software and associated documentation files the Software, to deal in the Software
without restriction, including without limitation the rights to use, copy, modify, merge,
publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons
to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or
substantial portions of the Software.

THE SOFTWARE IS PROVIDED 'AS IS', WITHOUT WARRANTY OF ANY KIND, EXPRESS
OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES
OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
OTHER DEALINGS IN THE SOFTWARE.*/


import React, { useState, useRef, useEffect, useContext } from 'react'
import { Link } from 'react-router-dom'
import { Button, Grow, Paper, Popper, MenuItem, MenuList } from '@material-ui/core';
import { withStyles } from '@material-ui/styles';
import styled from 'styled-components'

import { Store } from '../Store';

const styles = theme => ({
  root: {
    display: 'flex',
    
  },
  paper: {
    marginRight: '2px',  
  },
});

const DropdownStyled = styled.div`
  *{
    margin: 0 !important;
    text-decoration: none;
  }
  Button{
    text-transform: capitalize;
  }

`


function Dropdown(props) {
  const [open, setOpen] = useState(false);


  const innerDropdown = useRef(null)

  const { state , dispatch } = useContext(Store)
    
  useEffect(()=>{
    const handleClickOutside = (event) => {
      innerDropdown.current && !innerDropdown.current.contains(event.target) && setOpen(false)
    }
      
    document.addEventListener('mousedown', handleClickOutside)

    return () => document.removeEventListener('mousedown', handleClickOutside)
  
  },[])


  const handleToggle = () => {
    setOpen(true)
    if(state.searchOpen)
      dispatch({
        type: 'HANDLE_SEARCH_BAR',
        opened: false
      })
  }

  return (
    <DropdownStyled ref={innerDropdown}>
      <Button
        aria-controls="menu-list-grow"
        aria-haspopup="true"
        onClick={handleToggle}
      >
        {props.name}
      </Button>
      { open &&
        <Popper open={open} keepMounted transition disablePortal>
          {({ TransitionProps, placement }) => (
            <Grow
              {...TransitionProps}
              style={{ transformOrigin: placement === 'bottom' ? 'center top' : 'center bottom' }}
            >
              <Paper id="menu-list-grow">
                <MenuList>
                  {
                    props.items.map((item)=>
                      <Link key={item.name} to={item.href} ><MenuItem>{item.name}</MenuItem></Link>
                    )
                  }
                </MenuList>
              </Paper>
            </Grow>
          )}
        </Popper>
      }
    </DropdownStyled>
  );
}

export default withStyles(styles)(Dropdown)
